@@ -184,21 +184,6 @@ def transformConjugationForm(verb, verbType, conjugationForm):
         elif conjugationForm.startswith("命令"):
             transformed+="こい"
 
-    elif verbType.startswith("ナ形容詞"):
-        transformed = verb[0:-1]
-        if conjugationForm in ["未然否定zu", "未然使役", "未然意思", "未然可能"]:
-            transformed+=""
-        elif conjugationForm.startswith("連用過去"):
-            transformed+=""
-        elif conjugationForm.startswith("連用希望") or conjugationForm=="未然否定nai":
-            transformed+="では"
-        elif conjugationForm.startswith("終止"):
-            transformed+=""
-        elif conjugationForm.startswith("連体"):
-            transformed+=""
-        elif conjugationForm.startswith("仮定"):
-            transformed+=""
-
     elif verb=="いい":
         transformed = ""
         if conjugationForm in ["未然否定zu", "未然使役", "未然意思", "未然可能"]:
@@ -215,24 +200,60 @@ def transformConjugationForm(verb, verbType, conjugationForm):
             transformed+="よけれ"
 
     elif verbType.startswith("判定詞"):
+        # 基本形+に+するの活用形
         transformed = verb[0:-1]
         if conjugationForm in ["未然否定zu", "未然使役", "未然意思", "未然可能"]:
             transformed+=""
         elif conjugationForm.startswith("連用過去"):
-            transformed+=""
+            transformed+="だっ"
         elif conjugationForm.startswith("連用希望") or conjugationForm=="未然否定nai":
             transformed+="では"
         elif conjugationForm.startswith("終止"):
-            transformed+=""
+            transformed+="だ"
         elif conjugationForm.startswith("連体"):
+            transformed+="な"
+        elif conjugationForm.startswith("仮定"):
+            transformed+="なら"
+
+    elif verbType.startswith("形容詞性名詞接尾辞"):
+        transformed = verb[0:-1]
+        # 基本形+に+するの活用形
+        if conjugationForm in ["未然否定zu", "未然使役", "未然意思", "未然可能"]:
             transformed+=""
+        elif conjugationForm.startswith("連用過去"):
+            transformed+="だっ"
+        elif conjugationForm.startswith("連用希望") or conjugationForm=="未然否定nai":
+            transformed+="では"
+        elif conjugationForm.startswith("終止"):
+            transformed+="だ"
+        elif conjugationForm.startswith("連体"):
+            transformed+="だ"
+        elif conjugationForm.startswith("仮定"):
+            transformed+="なら"
+
+    # 例：静か　便利　暇　素敵
+    elif verbType.startswith("ナ形容詞"):
+        transformed = verb[0:-1]
+        # 基本形+に+するの活用形
+        if conjugationForm in ["未然否定zu", "未然使役", "未然意思", "未然可能"]:
+            transformed+=""
+        elif conjugationForm.startswith("連用過去"):
+            transformed+="だっ"
+        elif conjugationForm.startswith("連用希望") or conjugationForm=="未然否定nai":
+            transformed+="では"
+        elif conjugationForm.startswith("終止"):
+            transformed+="だ"
+        elif conjugationForm.startswith("連体"):
+            transformed+="な"
         elif conjugationForm.startswith("仮定"):
             transformed+=""
 
-    elif "形容詞" in verbType:
+    # 例：暑い　美味しい　大きい　いい
+    elif verbType.startswith("イ形容詞"):
         transformed = verb[0:-1]
+        # 基本形+に+するの活用形
         if conjugationForm in ["未然否定zu", "未然使役", "未然意思", "未然可能"]:
-            transformed+="かろ"
+            transformed+="く"
         elif conjugationForm.startswith("連用過去"):
             transformed+="かっ"
         elif conjugationForm.startswith("連用希望") or conjugationForm=="未然否定nai":
@@ -242,7 +263,22 @@ def transformConjugationForm(verb, verbType, conjugationForm):
         elif conjugationForm.startswith("連体"):
             transformed+="い"
         elif conjugationForm.startswith("仮定"):
-            transformed+="けれ"
+            transformed+=""
+
+    # elif "形容詞" in verbType:
+    #     transformed = verb[0:-1]
+    #     if conjugationForm in ["未然否定zu", "未然使役", "未然意思", "未然可能"]:
+    #         transformed+="かろ"
+    #     elif conjugationForm.startswith("連用過去"):
+    #         transformed+="だっ"
+    #     elif conjugationForm.startswith("連用希望") or conjugationForm=="未然否定nai":
+    #         transformed+="く"
+    #     elif conjugationForm.startswith("終止"):
+    #         transformed+="い"
+    #     elif conjugationForm.startswith("連体"):
+    #         transformed+="い"
+    #     elif conjugationForm.startswith("仮定"):
+    #         transformed+="けれ"
     return transformed
 
 # formatList　可能　受け身　使役　過去　断定　否定　推定　様態　伝聞　例示　勧誘　打ち消し　自分の希望　他人の希望　前提確認　て　です・ます　終止　仮定　ください
@@ -278,10 +314,12 @@ phrases.append(phrase(word="受け身",mizen="れ",renyo="れ",syusi="れる",re
 phrases.append(phrase(word="受け身",mizen="れ",renyo="れ",syusi="れる",rentai="れる",katei="れれ",meirei="れろ",before_word_type="サ変動詞",conjugation="未然使役"))
 phrases.append(phrase(word="受け身",mizen="られ",renyo="られ",syusi="られる",rentai="られる",katei="られれ",meirei="られろ",before_word_type=None,conjugation="未然使役"))
 #動詞の直後しか許されない
+# checklist 母音「見る,出る,食べる」子音「住む,死ぬ,飛ぶ」カ「書く,咲く」ガ「嗅ぐ,急ぐ」促音系「買う,待つ,分かる」特殊「貸す,出す,来る,する」
 phrases.append(phrase(word="過去",mizen="だろ",renyo="だ",syusi="だ",rentai="だ",katei="だら",meirei="",before_word_type="子音動詞ガ行",conjugation="連用過去"))
 phrases.append(phrase(word="過去",mizen="だろ",renyo="だ",syusi="だ",rentai="だ",katei="だら",meirei="",before_word_type="子音動詞ナ行",conjugation="連用過去"))
 phrases.append(phrase(word="過去",mizen="だろ",renyo="だ",syusi="だ",rentai="だ",katei="だら",meirei="",before_word_type="子音動詞バ行",conjugation="連用過去"))
 phrases.append(phrase(word="過去",mizen="だろ",renyo="だ",syusi="だ",rentai="だ",katei="だら",meirei="",before_word_type="子音動詞マ行",conjugation="連用過去"))
+phrases.append(phrase(word="過去",mizen="だろ",renyo="だ",syusi="だ",rentai="だ",katei="だら",meirei="",before_word_type="子音動詞マ行",conjugation="連用過去"))
 phrases.append(phrase(word="過去",mizen="たろ",renyo="た",syusi="た",rentai="た",katei="たら",meirei="",before_word_type=None,conjugation="連用過去"))
 #命令形だと終止形+"な"
 #"ます"だと、未然形+"ん"
@@ -379,9 +417,15 @@ def transformVerb(verb,format_set):
         if engine_name == SegmentationEngine.JANOME:
             words = [ token.surface for token in engine.tokenize(verb)]
         if engine_name == SegmentationEngine.JUMAN:
-            words = [ mrph.midasi for mrph in engine.analysis(verb).mrph_list()]
-        if words is not None and words[-1] in kotodama_dic:
-            values = kotodama_dic[words[-1]]
+            words = [ mrph.genkei for mrph in engine.analysis(verb).mrph_list()]
+
+        if words is not None:
+            verb = "".join(words)
+            if words[-1] in kotodama_dic:
+                values = kotodama_dic[words[-1]]
+            elif words[-1]+"だ" in kotodama_dic:
+                values = kotodama_dic[words[-1]+"だ"]
+
         # もしdisableErrorが実行されていたら、valuesの中身を極力Noneにしない
         if disable_error_engine is not None:
             juman_result = disable_error_engine.analysis(verb)
@@ -390,20 +434,34 @@ def transformVerb(verb,format_set):
                     add_db(mrph)
 
     if values == None:
-        values = kotodama_dic[verb]
+        if verb in kotodama_dic:
+            values = kotodama_dic[verb]
+        elif verb+"だ" in kotodama_dic:
+            values = kotodama_dic[verb+"だ"]
+            verb = verb+"だ"
+
+    # 特定の数の多い用言に関してはendswithを許す
+    if values == None:
+        if verb.endswith("ある"):
+            # 最後が「だ」で終わるものはほとんどナ形容詞
+            # 一部の例外は辞書で事前にカバーする
+            values = ["ある","動詞","子音動詞ラ行"]
+        if verb.endswith("だ"):
+            # 最後が「い」で終わるものはほとんどい形容詞
+            # イ形容詞イ段とイ形容詞アウオ段の違いはここでは特に必要ではない
+            values = [verb,"形容詞","ナ形容詞"]
+        if verb.endswith("い"):
+            values = [verb,"形容詞","イ形容詞"]
 
     if values == None:
-        raise ValueError("辞書に定義されていない単語が入力されました。kotodama_dic.csvに「"+str(verb)+"」を追加してください")
+        raise ValueError("辞書に定義されていない単語%sが入力されました。kotodama_dic.csvに「%s」を追加してください" %(str(words),str(verb)))
+
+    print(values)
 
-    print("values %s" % str(values))
     target_verb = values[0]
     hinsi = values[1]
     katuyou1 = values[2]
 
-    if not format_set <= set(phrase_order):
-        warnings.warn(str(format_set - set(phrase_order))+"は対応していません", UserWarning)
-        format_set = format_set & set(phrase_order)
-
     for key in NG_dict:
         if key in format_set:
             for ng_tag in NG_dict[key]:
@@ -433,8 +491,6 @@ def transformVerb(verb,format_set):
             elif phrase_order[max(index_array)] in desu:
                 format_set.add("です")
 
-
-
     if "仮定" in format_set:
         nara = {"受け身","伝聞","様態","例示","勧誘","です・ます","て"} & format_set
         ba = {"過去","伝聞","勧誘","です・ます","て"} & format_set
@@ -443,12 +499,12 @@ def transformVerb(verb,format_set):
         elif len(ba)==0:
             format_set.add("仮定ba")
 
-
+    if not format_set <= set(phrase_order):
+        warnings.warn(str(format_set - set(phrase_order))+"は対応していません", UserWarning)
+        format_set = format_set & set(phrase_order)
 
     format_set = sorted(format_set, key=phrase_order.index)       
 
-
-
     phrase_list = []
     for i in range(len(format_set)):
         for phrase in phrases:
@@ -472,9 +528,8 @@ def transformVerb(verb,format_set):
                     phrase_list.append(phrase)
                     break
 
-    print("verb %s target_verb %s" % (verb, target_verb))
     header = verb.replace(target_verb,"")
-    print("header %s" % header)
+
     if len(phrase_list)!=0:
         transformed = header + transformConjugationForm(target_verb,katuyou1,phrase_list[0].conjugation)
     else:
@@ -528,8 +583,6 @@ def transformVerb(verb,format_set):
         if "らよう" in transformed :
             transformed = transformed.replace("らよう","ろう")
 
-        print(transformed)
-
     return transformed
 
 def joinMultipleVerb(verbs,format_set):
